@@ -1,7 +1,7 @@
 """ test using PEM as key - we shouldn't validate a HMAC token instead """
 # pylint: disable=wrong-import-order
 from test.common import payload, pub_pem, pub_key
-from test import jwt
+from test import python_jwt as jwt
 from datetime import timedelta
 from pyvows import Vows, expect
 
